/*
Copyright (c) Members of the EGEE Collaboration. 2004. 
See http://www.eu-egee.org/partners/ for details on the copyright
holders.  

Licensed under the Apache License, Version 2.0 (the "License"); 
you may not use this file except in compliance with the License. 
You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0 

Unless required by applicable law or agreed to in writing, software 
distributed under the License is distributed on an "AS IS" BASIS, 
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
See the License for the specific language governing permissions and 
limitations under the License. 
*/

package org.glite.security.util;

import java.io.File;
import java.io.IOException;

public class CAFilenameSplitter {
	public String m_baseFilename;
	public String m_hash;
	public int m_number;

	
	public static CAFilenameSplitter splitCAFilename(String caFilename) throws IOException {
		int lastSlash;
		int lastDot;
		CAFilenameSplitter parts = new CAFilenameSplitter();
		
		// search for the last slash and after that is the hash of the CA DN until the dot.
		lastSlash = caFilename.lastIndexOf(File.separatorChar);
		lastDot = caFilename.lastIndexOf('.');
		
		if(lastDot < lastSlash + 9){
			throw new IOException("Can't initialize a trustanchor with filename " + 
					caFilename + ", should be of format [path][\\/]hash.[0-9]*.");		
		}
		
		if(lastSlash != -1){
			parts.m_hash = caFilename.substring(lastSlash + 1, lastDot);
		}else{ // in case the file points to current dir, which shouldn't happen, but handle it anyway.
			parts.m_hash = caFilename.substring(0, lastDot);
		}
		
		// Get the number of the cert from the CA we're handling now.
		parts.m_number = Integer.decode(caFilename.substring(lastDot + 1));
		
		parts.m_baseFilename = caFilename.substring(0, lastDot);
		
		return parts;
	}
	
}
