/*
Copyright (c) Members of the EGEE Collaboration. 2004. 
See http://www.eu-egee.org/partners/ for details on the copyright
holders.  

Licensed under the Apache License, Version 2.0 (the "License"); 
you may not use this file except in compliance with the License. 
You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0 

Unless required by applicable law or agreed to in writing, software 
distributed under the License is distributed on an "AS IS" BASIS, 
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
See the License for the specific language governing permissions and 
limitations under the License. 
 */

package org.glite.security.util;

/**
 * An interface representing a DN, used in conjunction with DNHandler to manage
 * the DNs in an uniform way.
 * 
 * @author Joni Hahkala
 * 
 *         Created on September 8, 2003, 2:09 PM
 */
public interface DN {
    /**
     * Used to get the DN in X500 format. E.g. /C=US/O=Nerd Heaven/CN=Nerd
     * Nerdsten
     * 
     * @return String The DN in X500 format
     */
    String getX500();

    /**
     * Used to get the DN in RFC2253 format. E.g. CN=Nerd Nerdsten,O=Nerd
     * Heaven,C=US, emailaddress is showed as "Email"
     * 
     * @return String the DN in RFC2253 format
     */
    String getRFC2253();

    /**
     * Used to get the DN in RFC2253 format. E.g. CN=Nerd Nerdsten,O=Nerd
     * Heaven,C=US, but emailaddress is showed as "emailAddress".
     * 
     * @return String the DN in RFC2253 format
     */
    String getRFC2253v2();

    /**
     * Used to get the DN in canonical (small case) format. E.g. cn=nerd
     * nerdsten,o=nerd heaven,c=us
     * 
     * @return String the DN in canonical format
     */
    String getCanon();

    /**
     * Used to get a DN instance of the DN without the last CN. E.g. from
     * CN=proxy,CN=Nerd Nerdsten,O=Nerd Heaven,C=US to CN=Nerd Nerdsten,O=Nerd
     * Heaven,C=US
     * 
     * Useful for Grid applications to get the DN that is supposed to be in the
     * previous certifiacte in the chain
     * 
     * @param checkProxy
     *            a switch to define whether to check that the removed part is
     *            proxy identifier
     * @return DN the DN without the last proxy
     */
    DN withoutLastCN(boolean checkProxy);
}
