package org.glite.security.util;

import java.io.File;
import java.io.IOException;
import java.util.Vector;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.log4j.Logger;

public class TrustDirHandler {
    static final Logger LOGGER = Logger.getLogger(TrustDirHandler.class.getName());

    /** The directory containing the trustanchors */
    protected String m_dir;

    /** The list of files in the directory */
    protected File[] fileList;

    /** The CA file pattern */
    public final Pattern caPattern = Pattern.compile(".*\\.[0-9]");

    /**
     * Generates a new handler for the trust directory.
     *  
     * @param dir The directory containing the trust anchors, crls and namespace files.
     */
    public TrustDirHandler (String dir){
        this.m_dir = dir; 
    }

    /**
     * Reads the directory as a preparation.
     * 
     * @throws IOException
     */
    public void init() throws IOException{
        // open the directory or current dir if empty dir given.
        File directory = (m_dir.length() != 0) ? new File(m_dir)
        : new File(".").getAbsoluteFile();

        // list the files and dirs inside
        fileList = directory.listFiles();

    }

    /**
     * Lists the CA files.
     * 
     * @return the array of files matching the CA file pattern ".*\.[0-9]*"
     */
    public File[] getCAs(){
        Vector<File> cas = new Vector<File>();
        int index = 0;

        while(index < fileList.length){
            File currentFile = fileList[index];
            if(!currentFile.isDirectory()){
                Matcher matcher = caPattern.matcher(currentFile.getName());
                if(matcher.matches()){
                    cas.add(currentFile);
                }
            }
            index++;
        }

        return (File[])cas.toArray(new File[0]);

    }

}
