package org.glite.security.util.proxy;

import java.io.IOException;

import org.bouncycastle.asn1.DEROctetString;

/**
 * A class for handling the SAML extension in the Certificate.
 * 
 * @author joni.hahkala@cern.ch
 */
public class SAMLExtension {
    /** The OID for the SAML assertion. */
    public static final String SAML_OID = "1.3.6.1.4.1.3536.1.1.1.12";
    /** The legacy OID for the SAML assertion. */
    public static final String LEGACY_SAML_OID = "1.3.6.1.4.1.3536.1.1.1.10";

    private DEROctetString m_string = null;

    /**
     * Generates a new SAMLExtension object form the byte array
     * 
     * @param bytes
     * @throws IOException
     */
    public SAMLExtension(byte[] bytes) throws IOException {
        m_string = (DEROctetString) DEROctetString.fromByteArray(bytes);

    }

    /**
     * Used to generate an instance form the SAML assertion in String format.
     * 
     * @param samlString
     */
    public SAMLExtension(String samlString) {
        m_string = new DEROctetString(samlString.getBytes());
    }

    /**
     * Used to get the SAML assertion in String format.
     * 
     * @return The SAML sertion in string format.
     */
    public String getSAML() {
        return m_string.toString();
    }
}
